// Copyright 2022 The Inspektor Gadget authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package columns

import (
	"testing"

	"github.com/stretchr/testify/require"

	"github.com/inspektor-gadget/inspektor-gadget/pkg/columns/ellipsis"
)

func TestOptions(t *testing.T) {
	opts := GetDefault()

	WithAlignment(AlignRight)(opts)
	require.Equal(t, AlignRight, opts.DefaultAlignment)

	WithEllipsis(ellipsis.Middle)(opts)
	require.Equal(t, ellipsis.Middle, opts.DefaultEllipsis)

	WithWidth(2342)(opts)
	require.Equal(t, 2342, opts.DefaultWidth)
}
